@@ -1,5 +1,5 @@
 preprocess.ffdf <-
-function(dat, colNames, sortCol,  decreasing, scales, nBins, from, to) {
+function(dat, colNames, sortCol,  decreasing, scales, palet, nBins, from, to) {
    if (!require(ff)){
 		stop("This function needs package ff")
    }   
@@ -174,8 +174,8 @@ function(dat, colNames, sortCol,  decreasing, scales, nBins, from, to) {
 	tab$scales <- scales
 	tab$isNumber <- isNumber
 	## tab$row contains info about bins/y-axis
-	tab$rows <- list( heights = binSizes/vp$m 
-	                , y = c(0,cumsum(binSizes/vp$m)[-nBins])
+	tab$rows <- list( heights = -(binSizes/vp$m)
+	                , y = 1 - c(0,cumsum(binSizes/vp$m)[-nBins])
 	                , m = vp$m
 	                , from = from
 	                , to = to
@@ -184,6 +184,7 @@ function(dat, colNames, sortCol,  decreasing, scales, nBins, from, to) {
 	
 	## create column list
 	tab$columns <- list()
+	paletNr <- 1
 	for (i in 1:n) {
 		sortc <- ifelse(i %in% sortCol, ifelse(decreasing[which(i==sortCol)], "decreasing", "increasing"), "")
 		col <- list(name = colNames[i], isnumeric = isNumber[i], sort=sortc)
@@ -193,6 +194,8 @@ function(dat, colNames, sortCol,  decreasing, scales, nBins, from, to) {
 		} else {
 			col$freq <- datFreq[[colNames[i]]]$freqTable
 			col$categories <- datFreq[[colNames[i]]]$categories
+			col$palet <- palet[paletNr]
+			paletNr <- ifelse(paletNr==length(palet), 1, paletNr + 1)
 		}
 		tab$columns[[i]] <- col
 	}
